pub struct SendRequest<B> { /* private fields */ }Available on crate feature
client and (crate features http1 or http2) only.Expand description
The sender side of an established connection.
Implementations
Sourceimpl<B> SendRequest<B>
impl<B> SendRequest<B>
Sourcepub fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<()>>
Polls to determine whether this sender can be used yet for a request.
If the associated connection is closed, this returns an Error.
Sourcepub async fn ready(&mut self) -> Result<()>
pub async fn ready(&mut self) -> Result<()>
Waits until the dispatcher is ready
If the associated connection is closed, this returns an Error.
Sourcepub fn is_ready(&self) -> bool
pub fn is_ready(&self) -> bool
Checks if the connection is currently ready to send a request.
Note
This is mostly a hint. Due to inherent latency of networks, it is possible that even after checking this is ready, sending a request may still fail because the connection was closed in the meantime.
Sourceimpl<B> SendRequest<B>where
B: Body + 'static,
impl<B> SendRequest<B>where
B: Body + 'static,
Sourcepub fn send_request(
&mut self,
req: Request<B>,
) -> impl Future<Output = Result<Response<IncomingBody>>>
pub fn send_request( &mut self, req: Request<B>, ) -> impl Future<Output = Result<Response<IncomingBody>>>
Sends a Request on the associated connection.
Returns a future that if successful, yields the Response.
Note
There are some key differences in what automatic things the Client
does for you that will not be done here:
Clientrequires absolute-formUris, since the scheme and authority are needed to connect. They aren’t required here.- Since the
Clientrequires absolute-formUris, it can add theHostheader based on it. You must add aHostheader yourself before calling this method. - Since absolute-form
Uris are not required, if received, they will be serialized as-is.