#[no_mangle]
pub extern "C" fn hyper_error_print(
err: *const hyper_error,
dst: *mut u8,
dst_len: size_t,
) -> size_tAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Print the details of this error to a buffer.
The dst_len value must be the maximum length that the buffer can
store.
The return value is number of bytes that were written to dst.